@@ -96,6 +96,11 @@ class PairtreeStorageClient(object):
     def __hex2char(self, m):
         return ppath.hex2char(m)
 
+    def _rm_uribase(self, id):
+        if id.startswith(self.uri_base):
+            return id[len(self.uri_base):]
+        return id
+
     def id_encode(self, id):
         """
         The identifier string is cleaned of characters that are expected to occur rarely
@@ -198,8 +203,9 @@ class PairtreeStorageClient(object):
         @type id: identifier
         @returns: A directory path to the object's root directory
         """
+        
 #        return os.sep.join(self._id_to_dir_list(id))
-        return ppath.id_to_dirpath(id, self.pairtree_root, self.shorty_length)
+        return ppath.id_to_dirpath(self._rm_uribase(id), self.pairtree_root, self.shorty_length)
 
     def _id_to_dir_list(self, id):
         """
@@ -218,7 +224,7 @@ class PairtreeStorageClient(object):
 #            dirpath.append(enc_id[:self.shorty_length])
 #            enc_id = enc_id[self.shorty_length:]
 #        return dirpath
-        return ppath.id_to_dir_list(id, self.pairtree_root, self.shorty_length)
+        return ppath.id_to_dir_list(self._rm_uribase(id), self.pairtree_root, self.shorty_length)
         
     def _init_store(self):
         """
@@ -312,8 +318,7 @@ class PairtreeStorageClient(object):
         @type id: identifier
         @returns: L{PairtreeStorageObject}
         """
-        if id.startswith(self.uri_base):
-            id = id[len(self.uri_base):]
+        id = self._rm_uribase(id)
         dirpath = os.path.join(self._id_to_dirpath(id))
         if not os.path.exists(dirpath):
             os.makedirs(dirpath)
@@ -488,7 +493,7 @@ class PairtreeStorageClient(object):
         file_path = stream_name
         if path:
             file_path = os.path.join(path, stream_name)
-        url_prefix = ppath.id_to_url(id, self.pairtree_root, self.shorty_length)
+        url_prefix = ppath.id_to_url(self._rm_uribase(id), self.pairtree_root, self.shorty_length)
         return os.sep.join((url_prefix, file_path))
 
     def get_stream(self, id, path, stream_name, streamable=False):
@@ -660,9 +665,7 @@ class PairtreeStorageClient(object):
             id = self._get_new_id()
             return self._create(id)
         
-        
-        if id.startswith(self.uri_base):
-            id = id[len(self.uri_base):]
+        id = self._rm_uribase(id)
              
         if self.exists(id):
             return PairtreeStorageObject(id, self)
